mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Khushal Chitturi <khushalchitturi@gmail.com>
To: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Cc: Michael Straube <straube.linux@gmail.com>,
	Hans de Goede <hansg@kernel.org>,
	Dan Carpenter <dan.carpenter@linaro.org>,
	linux-staging@lists.linux.dev, linux-kernel@vger.kernel.org,
	Khushal Chitturi <khushalchitturi@gmail.com>
Subject: [PATCH 7/9] staging: rtl8723bs: rename local variables to snake_case
Date: Mon, 12 Jan 2026 00:06:28 +0530	[thread overview]
Message-ID: <20260111183630.12816-8-khushalchitturi@gmail.com> (raw)
In-Reply-To: <20260111183630.12816-1-khushalchitturi@gmail.com>

Rename local CamelCase variables in rtw_xmit.c to
follow the kernel naming conventions.

Signed-off-by: Khushal Chitturi <khushalchitturi@gmail.com>
---
 drivers/staging/rtl8723bs/core/rtw_xmit.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/drivers/staging/rtl8723bs/core/rtw_xmit.c b/drivers/staging/rtl8723bs/core/rtw_xmit.c
index 418ca141e656..5852209c702b 100644
--- a/drivers/staging/rtl8723bs/core/rtw_xmit.c
+++ b/drivers/staging/rtl8723bs/core/rtw_xmit.c
@@ -401,10 +401,10 @@ static void update_attrib_vcs_info(struct adapter *padapter, struct xmit_frame *
 
 			/* check HT op mode */
 			if (pattrib->ht_en) {
-				u8 HTOpMode = pmlmeinfo->HT_protection;
+				u8 ht_op_mode = pmlmeinfo->HT_protection;
 
-				if ((pmlmeext->cur_bwmode && (HTOpMode == 2 || HTOpMode == 3)) ||
-					(!pmlmeext->cur_bwmode && HTOpMode == 3)) {
+				if ((pmlmeext->cur_bwmode && (ht_op_mode == 2 || ht_op_mode == 3)) ||
+					(!pmlmeext->cur_bwmode && ht_op_mode == 3)) {
 					pattrib->vcs_mode = RTS_CTS;
 					break;
 				}
@@ -603,17 +603,17 @@ static void set_qos(struct pkt_file *ppktfile, struct pkt_attrib *pattrib)
 {
 	struct ethhdr etherhdr;
 	struct iphdr ip_hdr;
-	s32 UserPriority = 0;
+	s32 user_priority = 0;
 
 	_rtw_open_pktfile(ppktfile->pkt, ppktfile);
 	_rtw_pktfile_read(ppktfile, (unsigned char *)&etherhdr, ETH_HLEN);
 
 	/*  get UserPriority from IP hdr */
 	if (pattrib->ether_type == 0x0800) {
 		_rtw_pktfile_read(ppktfile, (u8 *)&ip_hdr, sizeof(ip_hdr));
-		UserPriority = ip_hdr.tos >> 5;
+		user_priority = ip_hdr.tos >> 5;
 	}
-	pattrib->priority = UserPriority;
+	pattrib->priority = user_priority;
 	pattrib->hdrlen = WLAN_HDR_A3_QOS_LEN;
 	pattrib->subtype = WIFI_QOS_DATA_TYPE;
 }
@@ -603,17 +603,17 @@ static void set_qos(struct pkt_file *ppktfile, struct pkt_attrib *pattrib)
 	_rtw_pktfile_read(ppktfile, (unsigned char *)&etherhdr, ETH_HLEN);
 
-	/*  get UserPriority from IP hdr */
+	/*  get user_priority from IP hdr */
 	if (pattrib->ether_type == 0x0800) {
 		_rtw_pktfile_read(ppktfile, (u8 *)&ip_hdr, sizeof(ip_hdr));
-- 
2.52.0


  parent reply	other threads:[~2026-01-11 18:37 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-01-11 18:36 [PATCH 0/9] staging: rtl8723bs: coding style and refactoring cleanups Khushal Chitturi
2026-01-11 18:36 ` [PATCH 1/9] staging: rtl8723bs: fix operator and type cast spacing Khushal Chitturi
2026-01-11 18:36 ` [PATCH 2/9] staging: rtl8723bs: remove empty branches Khushal Chitturi
2026-01-12  8:02   ` Dan Carpenter
2026-01-11 18:36 ` [PATCH 3/9] staging: rtl8723bs: simplify boolean expressions Khushal Chitturi
2026-01-12  8:18   ` Dan Carpenter
2026-01-11 18:36 ` [PATCH 4/9] staging: rtl8723bs: replace msleep with usleep_range in rtw_xmit.c Khushal Chitturi
2026-01-11 18:36 ` [PATCH 5/9] staging: rtl8723bs: split chained assignments Khushal Chitturi
2026-01-12  8:01   ` Dan Carpenter
2026-01-11 18:36 ` [PATCH 6/9] staging: rtl8723bs: rename struct members to snake_case Khushal Chitturi
2026-01-11 18:36 ` Khushal Chitturi [this message]
2026-01-11 18:36 ` [PATCH 8/9] staging: rtl8723bs: replace N_BYTE_ALIGMENT with PTR_ALIGN Khushal Chitturi
2026-01-11 18:36 ` [PATCH 9/9] staging: rtl8723bs: fix line length and alignment issues Khushal Chitturi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260111183630.12816-8-khushalchitturi@gmail.com \
    --to=khushalchitturi@gmail.com \
    --cc=dan.carpenter@linaro.org \
    --cc=gregkh@linuxfoundation.org \
    --cc=hansg@kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-staging@lists.linux.dev \
    --cc=straube.linux@gmail.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®